@@ -6,12 +6,14 @@ from PySide6.QtGui import QIcon
 from PySide6.QtMultimedia import QSoundEffect
 from PySide6.QtWidgets import QWidget, QMessageBox
 
+from frontengine.utils.logging.loggin_instance import front_engine_logger
 from frontengine.utils.multi_language.language_wrapper import language_wrapper
 
 
 class SoundEffectWidget(QWidget):
 
     def __init__(self, sound_path: str):
+        front_engine_logger.info(f"Init SoundEffectWidget sound_path: {sound_path}")
         super().__init__()
         self.volume: float = 1
         self.setWindowFlag(
@@ -21,12 +23,12 @@ class SoundEffectWidget(QWidget):
             Qt.WindowType.Tool
         )
         self.setAttribute(Qt.WidgetAttribute.WA_TranslucentBackground)
+        self.setAttribute(Qt.WidgetAttribute.WA_DeleteOnClose)
         self.sound_player = QSoundEffect()
         self.sound_path = Path(sound_path)
         if self.sound_path.exists() and self.sound_path.is_file():
             # QUrl non ascii path encode, Avoid read wrong path and file name
-            source = QUrl.fromLocalFile(str(self.sound_path).encode())
-            source = source.fromEncoded(source.toEncoded())
+            source = QUrl.fromLocalFile(str(self.sound_path))
             print(f"Origin file {str(self.sound_path)}")
             self.sound_player.setSource(source)
             # -2 means loop forever
@@ -44,9 +46,11 @@ class SoundEffectWidget(QWidget):
             self.setWindowIcon(QIcon(str(self.icon_path)))
 
     def set_sound_effect_variable(self, volume: float = 1) -> None:
+        front_engine_logger.info(f"SoundEffectWidget set_sound_effect_variable volume:{volume}")
         self.volume = volume
         self.sound_player.setVolume(self.volume)
 
     def closeEvent(self, event) -> None:
+        front_engine_logger.info(f"SoundEffectWidget closeEvent event:{event}")
         super().closeEvent(event)
         self.sound_player.stop()
